Gb

Struct Gb 

pub struct Gb<E: Executor = DirectExecutor> {
    pub cpustate: Gbz80State,
    pub mmu: Box<GbMmu>,
    pub button_states: ButtonStates,
    pub serial: SerialState,
    pub timer: TimerState,
    pub apu: ApuState,
    pub ppu: PpuState,
    /* private fields */
}
Represents a “real” gameboy, by explicitly using the GbMmu for memory.

Fields

cpustate: Gbz80State

State of the CPU in the system.

mmu: Box<GbMmu>

MMU for the system.

button_states: ButtonStates

Joypad button states

serial: SerialState

State of serial data transfer.

timer: TimerState

State of timer updates

apu: ApuState

State of audio rendering

ppu: PpuState

State of video rendering

Implementations

Source

impl Gb

pub fn new(bios: BiosRom, cart: Cartridge) -> Self

Create a Gb with the given bios and cartridge, using the default executor.

Source

impl Gb<MicrocodeExecutor>

pub fn new_microcode(bios: BiosRom, cart: Cartridge) -> Self

Create a Gb with the given bios and cartridge, using the microcode executor

Source

impl Gb<DirectExecutorV2>

pub fn new_v2(bios: BiosRom, cart: Cartridge) -> Self

Create a Gb with the given bios and cartridge, using the V2 direct executor.

Source

impl Gb<SteppingExecutor>

pub fn new_stepping(bios: BiosRom, cart: Cartridge) -> Self

Create a Gb with the given bios and cartridge, using the stepping executor

Source

impl<E> Gb<E>
where E: Executor, E::State: Default,

pub fn for_executor(bios: BiosRom, cart: Cartridge) -> Self

Create a Gb with the given bios and cartridge, using the executor specified by this type. Works for executors with state types that implement Default.

Source

impl<E: Executor> Gb<E>

pub fn for_config<C>(bios: BiosRom, cart: Cartridge, config: &C) -> Self
where C: ExecutorConfig<Executor = E>,

Create a Gb with the given bios and cartridge, using the provided config to create the initial state of the executor.

pub fn tick(&mut self)

Tick forward by one instruction, executing background and graphics processing operations as needed.

pub fn set_sample_rate(&mut self, sample_rate: u32)

Set the sample rate for the APU.

pub fn display_ready(&self) -> bool

Returns true if the PPU finished a frame this tick and the display is ready to be sent out.

pub fn get_ready_frame(&self) -> Option<&[(u8, u8, u8)]>

If the display is ready, get a reference to the PPU frame buffer.

pub fn elapsed_mcycles(&self) -> u64

Get the total number of mcycles elapsed since emulator start.

pub fn elapsed_time(&self) -> Duration

Get the total duration since the emulator started (based on the number of m-cycles elapsed.