CustomDefault

Trait CustomDefault 

pub trait CustomDefault {
    // Required method
    fn custom_default() -> Self;
}
Workaround for the implementation of Default for arrays being so janky Separated from main MemDevice interface in case arrays get const defaults later

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<const N: usize> CustomDefault for [u8; N]

Implementors