pub struct SerialRegs {
pub serial_data: u8,
pub serial_control: u8,
}Expand description
Memory-mapped IO registers used by Serial connections.
Fields
serial_data: u8serial_control: u8Trait Implementations
Sourceimpl Clone for SerialRegs
impl Clone for SerialRegs
Sourcefn clone(&self) -> SerialRegs
fn clone(&self) -> SerialRegs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerialRegs
impl Debug for SerialRegs
Sourceimpl Default for SerialRegs
impl Default for SerialRegs
Sourcefn default() -> SerialRegs
fn default() -> SerialRegs
Returns the “default value” for a type. Read more
Sourceimpl MemDevice for SerialRegs
impl MemDevice for SerialRegs
Sourceconst LEN: usize = 2usize
const LEN: usize = 2usize
Length of this MemDevice in bytes. Reads and writes must always be within the device.
Sourcefn read_byte_relative(&self, addr: RelativeAddr) -> u8
fn read_byte_relative(&self, addr: RelativeAddr) -> u8
Read the byte at the specified address. Read more
Sourcefn read_bytes_relative(&self, addr: RelativeAddr, data: &mut [u8])
fn read_bytes_relative(&self, addr: RelativeAddr, data: &mut [u8])
Read a range of bytes into a slice. The read bytes must not wrap past the end of
the device.
Sourcefn write_byte_relative(&mut self, addr: RelativeAddr, val: u8)
fn write_byte_relative(&mut self, addr: RelativeAddr, val: u8)
Write the byte at the sepcified address. Read more
Sourcefn write_bytes_relative(&mut self, addr: RelativeAddr, data: &[u8])
fn write_bytes_relative(&mut self, addr: RelativeAddr, data: &[u8])
Write a range of bytes into memory from a slice. The slice must not exceed the
length of the MemDevice.
Sourcefn read_relative_into<V>(&self, addr: RelativeAddr, dest: &mut V)where
V: MemValue,
fn read_relative_into<V>(&self, addr: RelativeAddr, dest: &mut V)where
V: MemValue,
Read a typed value from this MemDevice. The value must be fully contained within
this device.
Sourcefn read_relative<V>(&self, addr: RelativeAddr) -> V
fn read_relative<V>(&self, addr: RelativeAddr) -> V
Read a typed value from this MemDevice. The value must be fully contained within
this device.
Sourcefn write_relative_from<V>(&mut self, addr: RelativeAddr, source: &V)where
V: MemValue,
fn write_relative_from<V>(&mut self, addr: RelativeAddr, source: &V)where
V: MemValue,
Write a typed value into this MemDevice. The value must fit fully within the
device.
Sourcefn write_relative<V>(&mut self, addr: RelativeAddr, val: V)where
V: MemValue,
fn write_relative<V>(&mut self, addr: RelativeAddr, val: V)where
V: MemValue,
Write a typed value into this MemDevice. The value must fit fully within the
device.
Sourceimpl PartialEq for SerialRegs
impl PartialEq for SerialRegs
impl Eq for SerialRegs
impl StructuralPartialEq for SerialRegs