pub trait CustomDefault {
// Required method
fn custom_default() -> Self;
}Expand description
Workaround for the implementation of Default for arrays being so janky Separated from main MemDevice interface in case arrays get const defaults later
Required Methods
fn custom_default() -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.