pub trait MemSource {
// Required methods
fn get_byte(self) -> u8;
fn get_bytes(self, data: &mut [u8]);
}Expand description
Helper trait for MemValue which allows it to work with both MemDevice and
RootMemDevice and does not require it to know about addresses.
This trait represents memory in a particular MemDevice at a particular address which can be read from.