pub struct DmaState { /* private fields */ }Expand description
State of the Direct Memory Access system.
Implementations
Sourceimpl DmaState
impl DmaState
Sourcepub fn source_addr(&self) -> u16
pub fn source_addr(&self) -> u16
Get the source address for the DMA read.
This returns an absolute address within the GameBoy address space.
Sourcepub fn dest_addr(&self) -> RelativeAddr
pub fn dest_addr(&self) -> RelativeAddr
Gets the destination address for the DMA read.
This is a relative address within OAM. The relative base is the default address that OAM is mapped to. Note that because of how RelativeAddr works, this address will be valid for a read directly from OAM no matter where OAM is mapped, however the “raw” address may be wrong if OAM is not mapped in its normal location.